==> haskell-vector-th-unbox-0.2.1.6-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-BKkNIOMf3NXBnJmS8233Oc
key: vector-th-unbox-0.2.1.6-BKkNIOMf3NXBnJmS8233Oc
license: BSD-3-Clause
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: 33e25ed7d1432b69ad461f891d6e853a
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.6.3/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-8.6.3/site-local/vector-th-unbox-0.2.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-BKkNIOMf3NXBnJmS8233Oc
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-th-unbox-0.2.1.6-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vector-th-unbox.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vector-th-unbox
version: 0.2.1.6
id: vector-th-unbox-0.2.1.6-1sxJpESaRmTGhnhBOhDreI
key: vector-th-unbox-0.2.1.6-1sxJpESaRmTGhnhBOhDreI
license: BSD-3-Clause
copyright: © 2012−2015 Liyang HU
maintainer: Liyang HU <vector-th-unbox@liyang.hu>
author: Liyang HU <vector-th-unbox@liyang.hu>
stability: experimental
synopsis: Deriver for Data.Vector.Unboxed using Template Haskell
description:
    A Template Haskell deriver for unboxed vectors, given a pair of coercion
    functions to and from some existing type with an Unbox instance.
    .
    Refer to "Data.Vector.Unboxed.Deriving" for documentation and examples.
category: Data
abi: 8903d5fc9f8ead4730665e259608cf52
exposed: True
exposed-modules:
    Data.Vector.Unboxed.Deriving
import-dirs: /usr/lib/ghc-8.6.4/site-local/vector-th-unbox-0.2.1.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/vector-th-unbox-0.2.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/vector-th-unbox-0.2.1.6
hs-libraries: HSvector-th-unbox-0.2.1.6-1sxJpESaRmTGhnhBOhDreI
depends:
    base-4.12.0.0 template-haskell-2.14.0.0
    vector-0.12.0.2-AoZ9EwUsgIW1yrOc105QXH
haddock-interfaces: /usr/share/doc/haskell-vector-th-unbox/html/vector-th-unbox.haddock
haddock-html: /usr/share/doc/haskell-vector-th-unbox/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
